local NekoLoot = LibStub("AceAddon-3.0"):GetAddon("NekoLoot")
local L = LibStub("AceLocale-3.0"):GetLocale("NekoLoot")

local backdrop = {
	bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background", tile = true, tileSize = 32,
	edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border", edgeSize = 32,
	insets = {left = 11, right = 12, top = 12, bottom = 11},
}

local function CreateDialogFrame(dialogName)
	local dialogFrame = CreateFrame("Frame", dialogName, UIParent)
	dialogFrame:SetFrameStrata("DIALOG")
	dialogFrame:SetToplevel(true)
	dialogFrame:EnableMouse(true)
	dialogFrame:SetClampedToScreen(true)
	dialogFrame:SetWidth(360)
	dialogFrame:SetHeight(160)
	dialogFrame:SetBackdrop(backdrop)
	dialogFrame:SetPoint("TOP", 0, -100)
	dialogFrame:Hide()
	return dialogFrame
end

-- creates an error dialog
-- dialogName		: name of the created dialog
-- dialogMsg		: message to display on the dialog
-- buttonText		: text to display on the button
-- buttonPos		: position of the clickable button
-- buttonHandler	: function to call when button is clicked
function NekoLoot:CreateDialog(dialogName, dialogMsg, buttonText, buttonPos, buttonHandler)
	if not self.dialog or (self.dialog:GetName() ~= dialogName) then
		local dialogFrame = CreateDialogFrame(dialogName)

		titleRegion = dialogFrame:CreateTitleRegion()
		titleRegion:SetAllPoints(dialogFrame)

		header = dialogFrame:CreateTexture(nil, "ARTWORK")
		header:SetTexture("Interface\\DialogFrame\\UI-DialogBox-Header")
		header:SetWidth(256); header:SetHeight(64)
		header:SetPoint("TOP", 0, 12)
		
		title = dialogFrame:CreateFontString("ARTWORK")
		title:SetFontObject("GameFontNormal")
		title:SetPoint("TOP", header, "TOP", 0, -14)
		title:SetText("NekoLoot")

		desc = dialogFrame:CreateFontString("ARTWORK")
		desc:SetFontObject("GameFontHighlight")
		desc:SetJustifyV("TOP")
		desc:SetJustifyH("LEFT")
		desc:SetPoint("TOPLEFT", 18, -32)
		desc:SetPoint("BOTTOMRIGHT", -18, 48)
		desc:SetText(dialogMsg)
	
		button = CreateFrame("CheckButton", "NekoLootErrorDialog", dialogFrame, "OptionsButtonTemplate")
		_G[button:GetName() .. "Text"]:SetText(buttonText)
		
		button:SetScript("OnClick", function(self) 
			buttonHandler()
			end)
			
		if buttonPos == "BOTTOM" then button:SetPoint(buttonPos, 0, 14)
		else button:SetPoint(buttonPos, -14, 14) end
		
		self.dialog = dialogFrame
	end
	self.dialog:Show()
end